@@ -1,8 +1,11 @@
+import os
 from decouple import config
+import pkg_resources
 
 JWT_SECRET = config("JWT_SECRET")
 GOOGLE_CLIENT_ID = config("GOOGLE_CLIENT_ID")
 GOOGLE_CLIENT_SECRET = config("GOOGLE_CLIENT_SECRET")
+GOOGLE_SECRET = config("GOOGLE_SECRET")
 REDIRECT_URL = config("REDIRECT_URL")
 MAIL_USERNAME =config('MAIL_USERNAME')
 MAIL_PASSWORD =config('MAIL_PASSWORD')
@@ -13,4 +16,9 @@ MAIL_FROM_NAME =config('MAIL_FROM_NAME')
 TEMPLATE_FOLDER = config('TEMPLATE_FOLDER')
 EMAIL_VERIFICATION_TEMPLATE = config('EMAIL_VERIFICATION_TEMPLATE')
 PASSWORD_RESET_TEMPLATE = config('PASSWORD_RESET_TEMPLATE')
-FILES_BASE_FOLDER = config('FILES_BASE_FOLDER')
\ No newline at end of file
+FILES_BASE_FOLDER = config('FILES_BASE_FOLDER')
+
+# If the templates folder is not valid, then we use the bigfastapi templates folder
+
+if os.path.exists(TEMPLATE_FOLDER) == False:
+    TEMPLATE_FOLDER = pkg_resources.resource_filename('bigfastapi', 'templates/')
\ No newline at end of file
